<?php
/**
 * @file
 * template.php
 */

include_once(drupal_get_path('theme', 'mojo') . '/inc/process.inc');
include_once(drupal_get_path('theme', 'mojo') . '/inc/theme.inc');

// Auto-rebuild the theme registry during theme development.
if (theme_get_setting('rebuild_registry')) {
  // Rebuild .info data.
  system_rebuild_theme_data();
  // Rebuild theme registry.
  drupal_theme_rebuild();
  drupal_set_message(t('Theme registry is being rebuilt on every page. !link on production sites.', array('!link' => l(t('Turn this off'), 'admin/appearance/settings/mojo#div-mojo-registry'))), 'warning');
}

// Add Modernizr.
if (theme_get_setting('use_modernizr')) {
  drupal_add_js(drupal_get_path('theme', 'mojo') . '/js/modernizr.min.js', array('scope' => 'header', 'every_page' => TRUE));
}

// Optimize the scope of scripts for front-end performance.
function mojo_js_alter(&$javascript) {
  if (theme_get_setting('optimize_scripts')) {
    foreach ($javascript as $key => $script) {
      if ($key != 'sites/all/themes/mojo/js/modernizr.min.js') {
        $javascript[$key]['scope'] = 'footer';
      }
    }
  }
}

/**
 * Implements hook_html_head_alter().
 */
function mojo_html_head_alter(&$head_elements) {

  // HTML5 charset declaration.
  $head_elements['system_meta_content_type']['#attributes'] = array(
    'charset' => 'utf-8'
  );

  // Add mobile meta tags.
  if (theme_get_setting('use_handheld_friendly')) {
    $head_elements['handheld_friendly'] = array(
      '#type' => 'html_tag',
      '#tag' => 'meta',
      '#attributes' => array(
        'name' => 'HandheldFriendly',
        'content' => 'true',
      ),
    );
  }

  if (theme_get_setting('use_mobile_optimized')) {
    $head_elements['mobile_optimized'] = array(
      '#type' => 'html_tag',
      '#tag' => 'meta',
      '#attributes' => array(
        'name' => 'MobileOptimized',
        'content' => '320',
      ),
    );
  }

  // Optimize mobile viewport.
  if (theme_get_setting('use_mobile_viewport')) {
    $head_elements['mobile_viewport'] = array(
      '#type' => 'html_tag',
      '#tag' => 'meta',
      '#attributes' => array(
        'name' => 'viewport',
        'content' => filter_xss(theme_get_setting('mobile_viewport_value')),
      ),
    );
  }

  // Force IE to use Chrome Frame if installed.
  if (theme_get_setting('use_chrome_frame')) {
    $head_elements['chrome_frame'] = array(
      '#type' => 'html_tag',
      '#tag' => 'meta',
      '#attributes' => array(
        'http-equiv' => 'X-UA-Compatible',
        'content' => 'IE=edge,chrome=1',
      ),
    );
  }

  // Remove image toolbar in IE.
  $head_elements['ie_image_toolbar'] = array(
    '#type' => 'html_tag',
    '#tag' => 'meta',
    '#attributes' => array(
      'http-equiv' => 'ImageToolbar',
      'content' => 'false',
    ),
  );

  // Better font rendering in IE.
  $head_elements['ie_cleartype'] = array(
    '#type' => 'html_tag',
    '#tag' => 'meta',
    '#attributes' => array(
      'http-equiv' => 'cleartype',
      'content' => 'on',
    ),
  );

}
