<?php
/**
 * @file
 * theme-settings.php
 */

function mojo_form_system_theme_settings_alter(&$form, $form_state) {
  $form['theme_settings']['toggle_logo']['#description'] = t('This logo will only be displayed when a user prints the page.');
  $form['javascript'] = array(
    '#type' => 'fieldset',
    '#title' => t('JavaScript settings'),
    '#attributes' => array('id' => 'mojo-js'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['javascript']['optimize_scripts'] = array(
    '#type' => 'checkbox',
    '#title' => t('Move scripts to the bottom.'),
    '#default_value' => theme_get_setting('optimize_scripts'),
    '#description' => t('Set the scope of all scripts (except Modernizr) to the footer<br />
                          For more information: !link',
                          array('!link' => l(t('Move Scripts to the Bottom'), 'http://developer.yahoo.com/blogs/ydn/posts/2007/07/high_performanc_5/'))
                          ),
    '#prefix' => '<strong>' . t('Script Performance') . ':</strong>',
  );
  $form['javascript']['use_modernizr'] = array(
    '#type' => 'checkbox',
    '#title' => t('Include Modernizr'),
    '#default_value' => theme_get_setting('use_modernizr'),
    '#description' => t('Include a reference the the !link JavaScript library.<br />
                          Requires manual download. Place modernizr.min.js in /sites/all/themes/mojo/js/ directory.',
                          array('!link' => l(t('Modernizr'), 'http://www.modernizr.com'))
                          ),
    '#prefix' => '<strong>' . t('Modernizr') . ':</strong>',
  );
  $form['breadcrumb'] = array(
    '#type' => 'fieldset',
    '#title' => t('Breadcrumb settings'),
    '#attributes' => array('id' => 'mojo-breadcrumb'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['breadcrumb']['breadcrumb_display'] = array(
    '#type' => 'select',
    '#title' => t('Display breadcrumb'),
    '#default_value' => theme_get_setting('breadcrumb_display'),
    '#options' => array(
        'yes' => t('Yes'),
        'admin' => t('Only in admin section'),
        'no' => t('No'),
        ),
  );
  $form['breadcrumb']['breadcrumb_separator'] = array(
    '#type' => 'textfield',
    '#title' => t('Breadcrumb separator'),
    '#description' => t('Text only. Don’t forget to include spaces.'),
    '#default_value' => theme_get_setting('breadcrumb_separator'),
    '#size' => 5,
    '#maxlength' => 10,
  );
  $form['breadcrumb']['breadcrumb_home'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show home page link in breadcrumb'),
    '#default_value' => theme_get_setting('breadcrumb_home'),
  );
  $form['breadcrumb']['breadcrumb_title'] = array(
    '#type' => 'checkbox',
    '#title' => t('Append the content title to the end of the breadcrumb'),
    '#default_value' => theme_get_setting('breadcrumb_title'),
  );
  $form['breadcrumb']['breadcrumb_trailing'] = array(
    '#type' => 'checkbox',
    '#title' => t('Append a separator to the end of the breadcrumb'),
    '#default_value' => theme_get_setting('breadcrumb_trailing'),
    '#description' => t('Useful when the breadcrumb is positioned just before the title.'),
  );
  $form['mobile_metatags'] = array(
    '#type' => 'fieldset',
    '#title' => t('Meta tags for mobile devices'),
    '#attributes' => array('id' => 'mojo-mobile-view-port'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['mobile_metatags']['use_handheld_friendly'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use handheld friendly meta tag'),
    '#description' => '<code>&lt;meta name="HandheldFriendly" content="true" /&gt;</code>',
    '#default_value' => theme_get_setting('use_handheld_friendly'),
  );
  $form['mobile_metatags']['use_mobile_optimized'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use mobile optimized meta tag'),
    '#description' => '<code>&lt;meta name="MobileOptimized" content="320" /&gt;</code>',
    '#default_value' => theme_get_setting('use_mobile_optimized'),
  );
  $form['mobile_metatags']['use_mobile_viewport'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use mobile viewport meta tag'),
    '#default_value' => theme_get_setting('use_mobile_viewport'),
  );
  $form['mobile_metatags']['mobile_viewport_value'] = array(
    '#type' => 'textfield',
    '#title' => t('Mobile viewport meta tag value'),
    '#default_value' => theme_get_setting('mobile_viewport_value'),
    '#description' => t('Suggested default: width=device-width, target-densitydpi=160dpi, initial-scale=1<br />
                          For more information: !link',
                          array('!link' => l(t('Viewport and Media Queries'), 'https://docs.google.com/present/view?id=dkx3qtm_22dxsrgcf4'))
                          ),
  );
  $form['misc'] = array(
    '#type' => 'fieldset',
    '#title' => t('Miscellaneous settings'),
    '#attributes' => array('id' => 'mojo-misc'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['misc']['use_chrome_frame'] = array(
    '#type' => 'checkbox',
    '#title' => t('Force IE to use Chrome Frame if installed.'),
    '#default_value' => theme_get_setting('use_chrome_frame'),
    '#description' => t('Ideally, this feature should be set in .htaccess. For more information: !link',
                          array('!link' => l(t('Google Chrome Frame'), 'http://www.chromium.org/developers/how-tos/chrome-frame-getting-started'))
                          ),
    '#prefix' => '<div id="div-mojo-dropdowns"><strong>' . t('Use Chrome Frame') . ':</strong>',
    '#suffix' => '</div>',
  );
  $form['misc']['use_dropdowns'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display the main menu as a drop-down menu.'),
    '#default_value' => theme_get_setting('use_dropdowns'),
    '#description' => t('Go to !link and select <em>Show as expanded</em> for each top-level menu item you want to show drop-downs for.',
                          array('!link' => l(t('admin/structure/menu/manage/main-menu'), 'admin/structure/menu/manage/main-menu'))
                          ),
    '#prefix' => '<div id="div-mojo-dropdowns"><strong>' . t('Main Menu Drop-downs') . ':</strong>',
    '#suffix' => '</div>',
  );
  $form['misc']['rebuild_registry'] = array(
    '#type' => 'checkbox',
    '#title' => t('Rebuild theme registry on every page.'),
    '#default_value' => theme_get_setting('rebuild_registry'),
    '#description' => t('During theme development, it can be very useful to continuously <a href="!link">rebuild the theme registry</a>. WARNING: this incurs a huge performance penalty and must be turned off on production websites.', array('!link' => 'http://drupal.org/node/173880#theme-registry')),
    '#prefix' => '<div id="div-mojo-registry"><strong>' . t('Theme Registry') . ':</strong>',
    '#suffix' => '</div>',
  );
}
